/**
 * PETALS - PETALS Services Platform. Copyright (C) 2007 EBM WebSourcing
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version. This library is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 * 
 * Initial developer(s): EBM WebSourcing
 * --------------------------------------------------------------------------
 * $Id: ComponentLifeCycle
 * 
 */

package org.ow2.petals.container.lifecycle;

import javax.naming.InitialContext;
import javax.transaction.TransactionManager;

import org.objectweb.util.monolog.api.Logger;
import org.ow2.petals.jbi.descriptor.original.generated.Jbi;
import org.ow2.petals.jbi.management.admin.AdminService;
import org.ow2.petals.jbi.messaging.endpoint.ServiceEndpoint;
import org.ow2.petals.jbi.messaging.registry.EndpointRegistry;
import org.ow2.petals.jbi.messaging.routing.RouterService;

/**
 * <p>
 * The ComponentContext needs to access some services such as the Router and so
 * on. Those services are implemented by Fractal components, that may
 * dynamically change during the runtime.
 * </p>
 * <p>
 * Thus, the ComponentContext can not reference directly those services. Each
 * time the ComponentContext uses those services, it retrieves through this
 * interface the good reference of the service. This interface is implemented by
 * the fractal components <code>Installer</code> and
 * <code>ComponentLifeCycle</code>.
 * </p>
 * 
 * @see org.ow2.petals.container.lifecycle.Installer
 * @see org.ow2.petals.container.lifecycle.ComponentLifeCycle
 * @author alouis, nsalatge
 * 
 */
public interface ComponentContextCommunication {

    /**
     * get the JBI Descriptor.
     * 
     * @return the JBI descriptor
     */
    Jbi getJBIDescriptor();

    /**
     * The installation directory of the component.
     * 
     * @return the installation root
     */
    String getInstallationRoot();

    /**
     * The working directory for the component.
     * 
     * @return the workspace root
     */
    String getWorkspaceRoot();

    /**
     * Get the Admin service.
     * 
     * @return the admin service
     */
    AdminService getAdminService();

    /**
     * The address of the component, as a Consumer.
     * 
     * @return the consumer endpoint
     */
    ServiceEndpoint getAddress();

    /**
     * Get the EndpointRegistry service.
     * 
     * @return the endpoint service
     */
    EndpointRegistry getEndpointRegistry();

    /**
     * The Logger for the component.
     * 
     * @return the logger
     */
    Logger getLogger();

    /**
     * Get the Router service.
     * 
     * @return the router
     */
    RouterService getRouterService();

    /**
     * The Initial context for the component.
     * 
     * @return the initial context
     */
    InitialContext getInitialContext();

    /**
     * Get the TransactionManager service.
     * 
     * @return the TransactionManager service
     */
    TransactionManager getTransactionManagerService();

}
