/**
 * PETALS: PETALS Services Platform
 * Copyright (C) 2005 EBM WebSourcing
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA.
 *
 * Initial developer(s): EBM WebSourcing
 * --------------------------------------------------------------------------
 * $Id$
 * --------------------------------------------------------------------------  
 */
package org.ow2.petals.jbi.management.autoload;

import java.io.File;
import java.io.FilenameFilter;

/**
 * filter for autoloading. Return true if the file is an archive : JAR or ZIP.
 * 
 * @author alouis
 * 
 */

final class ArchiveFileFilter implements FilenameFilter {

    private static ArchiveFileFilter instance = new ArchiveFileFilter();

    public static ArchiveFileFilter getInstance() {
        return ArchiveFileFilter.instance;
    }

    /**
     * @see java.io.FilenameFilter#accept(java.io.File, java.lang.String)
     */
    public boolean accept(File dir, String name) {
        
        // JAR and ZIP files are accepted.
        // When downloading a file with Firefox, a temporary file with the same
        // name suffixed by '.part' is created and must be rejected.
        final String lcName = name.toLowerCase();

        if ((lcName.endsWith("jar") || lcName.endsWith("zip"))
                && !new File(dir, name + ".part").exists()) {

            return true;
        }
        return false;
    }
}