/**
 * PETALS - PETALS Services Platform. Copyright (c) 2007 EBM Websourcing,
 * http://www.ebmwebsourcing.com/
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version. This library is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 * 
 * -------------------------------------------------------------------------
 * $Id$
 * -------------------------------------------------------------------------
 */

package org.ow2.petals.jbi.management.task;

import java.io.File;

import org.ow2.petals.jbi.descriptor.original.generated.Jbi;
import org.ow2.petals.jbi.management.Context;
import org.ow2.petals.jbi.management.util.PackageHelper;
import org.ow2.petals.kernel.api.server.PetalsException;
import org.ow2.petals.util.LoggingUtil;

/**
 * This task checks the validity of a package to install. <br/>
 * Inputs : unzipped package root {@link File} <br/>
 * Outputs : Entity name (String), {@link Jbi} <br/>
 * The task has got a non-robust approach : it stops at the first subtask failed<br />
 * and have the undo capability.<br />
 * 
 * @author ofabre
 * @author Frederic Gardes - eBM Websourcing
 */
public abstract class AbstractCheckPackageTask extends AbstractLoggableTask {

    public AbstractCheckPackageTask(LoggingUtil log) {
        super(log);
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.ow2.petals.processor.Task#execute(java.util.Map)
     */
    public void execute(Context context) throws Exception {
        File packageFile = context.getUnzipRoot();
        Jbi descriptor = PackageHelper.loadDescriptor(packageFile);
        this.checkPackage(descriptor, packageFile);

        context.setDescriptor(descriptor);
        context.setEntityName(this.extractEntityName(descriptor));
        context.setEntityVersion(this.extractEntityVersion(descriptor));

    }

    protected abstract String extractEntityName(Jbi descriptor);
    
    protected String extractEntityVersion(Jbi descriptor) {
        return null;
    }

    protected abstract void checkPackage(Jbi descriptor, File packageFile) throws PetalsException;

    /*
     * (non-Javadoc)
     * 
     * @see org.ow2.petals.processor.Task#undo(java.util.Map)
     */
    public void undo(Context context) throws Exception {
        // Nothing to do
    }
}
