/**
 * PETALS - PETALS Services Platform. Copyright (c) 2006 EBM Websourcing,
 * http://www.ebmwebsourcing.com/
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version. This library is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 * 
 * -------------------------------------------------------------------------
 * $Id: RemoveSAStateHolderTask.java 154 10 oct. 06 ofabre $
 * -------------------------------------------------------------------------
 */

package org.ow2.petals.jbi.management.task.deployment.undeploy;

import org.ow2.petals.jbi.management.Context;
import org.ow2.petals.jbi.management.task.AbstractLoggableTask;
import org.ow2.petals.system.systemstate.SystemStateService;
import org.ow2.petals.systemstate.generated.ServiceAssembly;
import org.ow2.petals.util.LoggingUtil;

/**
 * <p>
 * This task removes service assembly from state holder file.
 * </p>
 * <p>
 * This task MUST be executed with a {@link Context} containing:
 * <ul>
 * <li>service assembly name as entity name</li>
 * <li>archive URL</li>
 * <li>install URL</li>
 * </ul>
 * and returns following data in the {@link Context}:
 * <ul>
 * <li>the service assembly state holder ({@link ServiceAssembly}).</li>
 * </ul>
 * </p>
 * The task has got a robust approach : it tries to do all the subtasks and
 * doesn't have the undo capability.</p>
 * 
 * @author ofabre - EBM Websourcing
 * @author Frederic Gardes - eBM Websourcing
 */
public class RemoveSAStateHolderTask extends AbstractLoggableTask {

    /**
     * JBI Container :: Recovery Service
     */
    private final SystemStateService recoveryService;

    public RemoveSAStateHolderTask(LoggingUtil log, SystemStateService recoveryService) {
        super(log);
        this.recoveryService = recoveryService;
    }

    public void execute(Context context) throws Exception {
        String name = context.getEntityName();
        ServiceAssembly serviceAssemblyStateHolder = null;

        try {
            serviceAssemblyStateHolder = this.recoveryService
                    .deleteServiceAssemblyStateHolder(name);
        } catch (Exception e) {
            this.log
                    .error("The service assembly '" + name + "' state holder can not be removed", e);
        }

        context.setServiceAssemblyStateHolder(serviceAssemblyStateHolder);
    }

    public void undo(Context context) throws Exception {
        // TODO : recreate the service assembly state holder
    }

}
