/**
 * PETALS - PETALS Services Platform. Copyright (c) 2007 EBM Websourcing,
 * http://www.ebmwebsourcing.com/
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version. This library is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 * 
 * -------------------------------------------------------------------------
 * $Id$
 * -------------------------------------------------------------------------
 */

package org.ow2.petals.jbi.management.task.installation.install.sl;

import java.io.File;
import java.io.IOException;

import org.ow2.petals.jbi.management.task.AbstractCopyPackageToRepositoryTask;
import org.ow2.petals.system.repository.RepositoryService;
import org.ow2.petals.system.repository.exception.RepositoryException;
import org.ow2.petals.util.LoggingUtil;

/**
 * <p>
 * This task copy shared library package into the repository.
 * </p>
 * <p>
 * This task MUST be executed with a {@link Context} containing:
 * <ul>
 * <li>shared library name as entity name,</li>
 * <li>shared library version as entity version,</li>
 * <li>archive as exploded directory,</li>
 * </ul>
 * and returns following data in the {@link Context}:
 * <ul>
 * <li>the URL where the shared library is installed in the repository.</li>
 * </ul>
 * </p>
 * 
 * @author ofabre - EBM Websourcing
 * 
 */
public class CreateSLRepositoryTask extends AbstractCopyPackageToRepositoryTask {

    public CreateSLRepositoryTask(LoggingUtil log, RepositoryService repositorySrv) {
        super(log, repositorySrv);
    }

    @Override
    protected File copyEntityPackage(String entityName, String entityVersion, File packageFile)
            throws IOException, RepositoryException {
        return repositoryService.addSharedLibrary(entityName, entityVersion, packageFile);

    }

    @Override
    protected void removeEntityPackage(String entityName, String entityVersion) throws IOException {
        repositoryService.removeSharedLibrary(entityName, entityVersion);
    }

}
