/**
 * PETALS - PETALS Services Platform. Copyright (c) 2007 EBM Websourcing,
 * http://www.ebmwebsourcing.com/
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version. This library is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 * 
 * -------------------------------------------------------------------------
 * $Id$
 * -------------------------------------------------------------------------
 */

package org.ow2.petals.jbi.management.task.installation.uninstall.component;

import java.io.IOException;

import org.ow2.petals.jbi.management.Context;
import org.ow2.petals.jbi.management.task.AbstractLoggableTask;
import org.ow2.petals.system.repository.RepositoryService;
import org.ow2.petals.util.LoggingUtil;

/**
 * <p>
 * This task remove the component folder from the Petals repository.
 * </p>
 * <p>
 * This task MUST be executed with a {@link Context} containing:
 * <ul>
 * <li>component name as entity name,</li>
 * </ul>
 * and returns no data in the {@link Context}.</li> </ul>
 * </p>
 * <p>
 * The task has got a robust approach : it tries to do all the subtasks and
 * doesn't have the undo capability.
 * </p>
 * 
 * @author ofabre
 * @author Frederic Gardes - eBM Websourcing
 */
public class RemoveComponentRepositoryTask extends AbstractLoggableTask {

    private final RepositoryService repositoryService;

    public RemoveComponentRepositoryTask(LoggingUtil log, RepositoryService repositoryService) {
        super(log);
        this.repositoryService = repositoryService;
    }

    public void execute(Context context) throws Exception {
        String componentName = context.getEntityName();
        try {
            this.repositoryService.removeComponent(componentName);
        } catch (IOException e) {
            // TODO: rnaudin : reactivate the log when the problem of removing
            // opened descriptor would be totally solved
            // this.log.error(
            // "The component " + componentName +
            // " can not be removed from repository", e);
        }
    }

    public void undo(Context context) throws Exception {
        // TODO : recreate the component folder
    }

}
