/**
 * PETALS - PETALS Services Platform. Copyright (c) 2007 EBM Websourcing,
 * http://www.ebmwebsourcing.com/
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version. This library is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 * 
 * -------------------------------------------------------------------------
 * $Id$
 * -------------------------------------------------------------------------
 */

package org.ow2.petals.jbi.management.task.installation.uninstall.component;

import org.ow2.petals.jbi.management.Context;
import org.ow2.petals.jbi.management.task.AbstractLoggableTask;
import org.ow2.petals.system.systemstate.SystemStateService;
import org.ow2.petals.systemstate.SystemStateException;
import org.ow2.petals.systemstate.generated.Component;
import org.ow2.petals.util.LoggingUtil;

/**
 * <p>
 * This task removes the component from the state holder file.
 * </p>
 * <p>
 * This task MUST be executed with a {@link Context} containing:
 * <ul>
 * <li>component name as entity name,</li>
 * </ul>
 * and returns following data in the {@link Context}:
 * <ul>
 * <li>the component state holder ({@link Component}).</li>
 * </ul>
 * </p>
 * <p>
 * The task has got a robust approach : it tries to do all the subtasks and
 * doesn't have the undo capability.
 * </p>
 * 
 * @author ofabre - EBM Websourcing
 * @author fgardes - EBM Websourcing
 */
public class RemoveComponentStateHolderTask extends AbstractLoggableTask {

    private SystemStateService systemStateService;

    public RemoveComponentStateHolderTask(LoggingUtil log, SystemStateService systemStateService) {
        super(log);
        this.systemStateService = systemStateService;
    }

    public void execute(Context context) throws Exception {
        String componentName = context.getEntityName();
        Component componentStateHolder = null;

        try {
            componentStateHolder = this.systemStateService
                    .deleteComponentStateHolder(componentName);
        } catch (SystemStateException e) {
            this.log.error("The component '" + componentName + "' state holder can not be removed",
                    e);
        }

        context.setComponentStateHolder(componentStateHolder);

    }

    public void undo(Context context) throws Exception {
        // TODO : recreate the state holder
    }

}
