/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2008 INRIA, http://www.inria.fr
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id$
 * -------------------------------------------------------------------------
 */

package org.ow2.petals.jbi.management.transaction;

import java.io.Serializable;

import org.objectweb.jotm.Coordinator;

/**
 * Represents the transaction context to propagate through the
 * network, between petals nodes, with the message exchange
 * 
 * @author Nicolas Dolet, Philippe Merle - INRIA
 *
 */
public class PetalsTransactionContext implements Serializable {
    /**
     * The serial version UID
     */
    private static final long serialVersionUID = 1L;

    /**
     * The format id of the transaction
     */
    protected int formatID;

    /**
     * The global transaction id of the transaction
     */
    protected byte[] globalTransactionID;
    
    /**
     * The branch qualifier
     */
    protected byte[] branchQualifier;
    
    /**
     * The transaction coordinator
     */
    protected Coordinator coordinator;
    
    /**
     * The transaction timeout
     */
    protected int timeOut;

    //--------------------------------------------------------------------------
    // Getters
    //--------------------------------------------------------------------------
    
    public int getFormatID() {
        return formatID;
    }

    public byte[] getGlobalTransactionID() {
        return globalTransactionID;
    }

    public byte[] getBranchQualifier() {
        return branchQualifier;
    }

    public Coordinator getCoordinator() {
        return coordinator;
    }

    public int getTimeOut() {
        return timeOut;
    }

}
