/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2005-2010 EBM WebSourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

package org.ow2.petals.jbi.messaging.routing.monitoring;

import java.util.List;
import java.util.Map;

import javax.jbi.messaging.MessagingException;
import javax.xml.namespace.QName;

import org.ow2.petals.jmx.api.IPetalsMonitoringService;

/**
 * The NMR monitor MBean.
 * 
 * @author rnaudin
 * @since 3.1
 */
public interface RouterMonitorMBean extends IPetalsMonitoringService {

    /**
     * 
     * Get the exchange with the given exchange Id.
     * 
     * @param exchangeId
     * @return The exchange in a key/value form
     * 
     * @throws MessagingException
     *             Failed to retrieve the exchange
     */
    Map<String, String> getExchange(String exchangeId) throws MessagingException;

    /**
     * Get the history of the given exchange.
     * 
     * @param exchangeId
     *            the send/received history
     * @return
     * 
     * @throws MessagingException
     *             Failed to retrieve the exchange history
     */
    Map<String, Long> getExchangeHistory(String exchangeId) throws MessagingException;

    /**
     * Get the list of exchange Ids that has been sent or received at least once
     * and matching the duration
     * 
     * @param interfaceName
     *            The interface name that exchange targets. Can be {@code null}
     * @param serviceName
     *            The service name that exchange targets. Can be {@code null}
     * @param endpointName
     *            The endpoint name that exchange targets. Can be {@code null}
     * @param operationName
     *            The operation name that exchange targets. Can be {@code null}
     * @param startDate
     *            the start date
     * @param endDate
     *            the end date
     * @return the list of the exchange Ids
     * 
     * @throws MessagingException
     *             Failed to retrieve the list of exchange Ids
     */
    List<String> getExchangeIds(QName interfaceName, QName serviceName, String endpointName,
            QName operationName, long startDate, long endDate) throws MessagingException;

    /**
     * Get the number of exchange that has been sent or received at least once
     * and matching the duration
     * 
     * @param interfaceName
     *            The interface name that exchange targets. Can be {@code null}
     * @param serviceName
     *            The service name that exchange targets. Can be {@code null}
     * @param endpointName
     *            The endpoint name that exchange targets. Can be {@code null}
     * @param operationName
     *            The operation name that exchange targets. Can be {@code null}
     * @param startDate
     *            the start date
     * @param endDate
     *            the end date
     * @return the list of the exchange Ids
     * 
     * @throws MessagingException
     *             Failed to retrieve the list of exchange Ids
     */
    int getExchanges(QName interfaceName, QName serviceName, String endpointName,
            QName operationName, long startDate, long endDate) throws MessagingException;

    /**
     * Get the list of Router Monitor filter.
     * 
     * @return the list of Router Monitor filter in key/values form.
     */
    List<Map<String, String>> getMonitoredExchanges();

    /**
     * Activate the monitoring of the exchanges matching the given criteria.
     * 
     * @param interfaceName
     *            The interface name that exchange targets. Can be {@code null}
     * @param serviceName
     *            The service name that exchange targets. Can be {@code null}
     * @param endpointName
     *            The endpoint name that exchange targets. Can be {@code null}
     * @param operationName
     *            The operation name that exchange targets. Can be {@code null}
     * @param storeExchanges
     *            if {@code true}, the exchanges are stored in the Persistence
     *            Service.
     * 
     * @throws MessagingException
     *             A Router Monitor filter already exists on these criteria
     */
    void monitorExchanges(QName interfaceName, QName serviceName, String endpointName,
            QName operationName, boolean storeExchanges) throws MessagingException;

    /**
     * Deactivate the monitoring of the exchanges matching the given criteria.
     * 
     * @param interfaceName
     *            The interface name that exchange targets. Can be {@code null}
     * @param ServiceName
     *            The service name that exchange targets. Can be {@code null}
     * @param endpointName
     *            The endpoint name that exchange targets. Can be {@code null}
     * @param operationName
     *            The operation name that exchange targets. Can be {@code null}
     * 
     * @throws MessagingException
     *             No Router Monitor filter activated on the given criteria
     */
    void unmonitorExchanges(QName interfaceName, QName serviceName, String endpointName,
            QName operationName) throws MessagingException;

}
