/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2009 OW2, http://www.ow2.org/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id: $
 * -------------------------------------------------------------------------
 */
package org.ow2.petals.transport.platform.nio.selector;

import java.io.IOException;
import java.nio.channels.SocketChannel;


/**
 * Interface of the Fractal component associated to the NIO client.
 * 
 * @author Christophe DENEUX (Capgemini Sud)
 */
public interface NioClient {
	
	/**
     * The callback caller will close the socket channel next.
     *  
     * @param socketChannel The socket channel that has been detected as closed.
     */
    void onClose(final SocketChannel socketChannel);
    
    void onConnectionError(final IOException exception);
    
    /**
	 * Callbacks used by the TCP connection process
	 */
	void onIsConnected(final OutputSocketChannelContext oscc);
    
    /**
	 * Callbacks used by the TCP write process
	 */
	void onIsWritten() throws IOException;
    
	void onWriteError(final IOException exception) throws IOException;
	
	void send(final Object obj, final long timeout) throws IOException, InterruptedException;

}
