/**
 * PETALS: PETALS Services Platform Copyright (C) 2009 EBM WebSourcing
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or any later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 * 
 * Initial developer(s): EBM WebSourcing
 */
package org.ow2.petals.ws;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.Map;

import javax.jbi.management.ComponentLifeCycleMBean;

import org.objectweb.fractal.api.Component;
import org.objectweb.fractal.fraclet.annotation.annotations.FractalComponent;
import org.objectweb.fractal.fraclet.annotation.annotations.Interface;
import org.objectweb.fractal.fraclet.annotation.annotations.LifeCycle;
import org.objectweb.fractal.fraclet.annotation.annotations.Monolog;
import org.objectweb.fractal.fraclet.annotation.annotations.Provides;
import org.objectweb.fractal.fraclet.annotation.annotations.Requires;
import org.objectweb.fractal.fraclet.annotation.annotations.type.LifeCycleType;
import org.objectweb.util.monolog.api.Logger;
import org.ow2.petals.container.lifecycle.ServiceAssemblyLifeCycle;
import org.ow2.petals.container.lifecycle.SharedLibraryLifeCycle;
import org.ow2.petals.jbi.management.admin.AdminService;
import org.ow2.petals.kernel.ws.api.JBIArtefactsService;
import org.ow2.petals.kernel.ws.api.PEtALSWebServiceException;
import org.ow2.petals.kernel.ws.api.to.ServiceAssembly;
import org.ow2.petals.kernel.ws.api.to.SharedLib;
import org.ow2.petals.tools.ws.KernelWebService;
import org.ow2.petals.util.LoggingUtil;

/**
 * @author chamerling - eBM WebSourcing
 * 
 */
@FractalComponent
@Provides(interfaces = { @Interface(name = "webservice", signature = JBIArtefactsService.class),
        @Interface(name = "service", signature = KernelWebService.class) })
public class JBIArtefactsServiceImpl implements KernelWebService, JBIArtefactsService {

    @Monolog(name = "logger")
    private Logger logger;

    private LoggingUtil log;

    @org.objectweb.fractal.fraclet.annotation.annotations.Service(name = "component")
    private Component component;

    @Requires(name = "adminService", signature = AdminService.class)
    private AdminService adminService;

    @LifeCycle(on = LifeCycleType.START)
    protected void start() {
        this.log = new LoggingUtil(this.logger);
        this.log.debug("Starting...");
    }

    @LifeCycle(on = LifeCycleType.STOP)
    protected void stop() {
        this.log.debug("Stopping...");
    }

    /**
     * {@inheritDoc}
     */
    public Component getComponent() {
        return this.component;
    }

    /**
     * {@inheritDoc}
     */
    public List<ServiceAssembly> getServiceAssemblies() throws PEtALSWebServiceException {
        List<ServiceAssembly> result = new ArrayList<ServiceAssembly>();

        Map<String, ServiceAssemblyLifeCycle> sas = this.adminService.getServiceAssemblies();
        if (sas != null) {
            Iterator<String> iter = sas.keySet().iterator();
            while (iter.hasNext()) {
                String saName = iter.next();
                ServiceAssemblyLifeCycle sal = sas.get(saName);

                ServiceAssembly sa = new ServiceAssembly();
                sa.setState(sal.getCurrentState());
                sa.setName(saName);
                if (sal.getServiceAssembly().getIdentification() != null) {
                    sa
                            .setDescription(sal.getServiceAssembly().getIdentification()
                                    .getDescription());
                }
                result.add(sa);
            }
        }
        return result;
    }

    /**
     * {@inheritDoc}
     */
    public List<org.ow2.petals.kernel.ws.api.to.Component> getComponents()
            throws PEtALSWebServiceException {
        List<org.ow2.petals.kernel.ws.api.to.Component> result = new ArrayList<org.ow2.petals.kernel.ws.api.to.Component>();

        Map<String, ComponentLifeCycleMBean> lc = this.adminService
                .getBindingComponentsLifeCycles();
        if (lc != null) {
            Iterator<String> iter = lc.keySet().iterator();
            while (iter.hasNext()) {
                String name = iter.next();
                ComponentLifeCycleMBean clc = lc.get(name);
                org.ow2.petals.kernel.ws.api.to.Component c = new org.ow2.petals.kernel.ws.api.to.Component();
                c.setState(clc.getCurrentState());
                c.setName(name);
                c.setType(BINDING);
                result.add(c);
            }
        }

        lc = this.adminService.getServiceEnginesLifeCycles();
        if (lc != null) {
            Iterator<String> iter = lc.keySet().iterator();
            while (iter.hasNext()) {
                String name = iter.next();
                ComponentLifeCycleMBean clc = lc.get(name);
                org.ow2.petals.kernel.ws.api.to.Component c = new org.ow2.petals.kernel.ws.api.to.Component();
                c.setState(clc.getCurrentState());
                c.setName(name);
                c.setType(ENGINE);
                result.add(c);
            }
        }
        return result;
    }

    /**
     * {@inheritDoc}
     */
    public List<SharedLib> getSharedLibraries() throws PEtALSWebServiceException {
        List<SharedLib> result = new ArrayList<SharedLib>();

        Map<String, SharedLibraryLifeCycle> lc = this.adminService.getSharedLibraries();
        if (lc != null) {
            Iterator<String> iter = lc.keySet().iterator();
            while (iter.hasNext()) {
                String name = iter.next();
                SharedLibraryLifeCycle slc = lc.get(name);
                SharedLib sl = new SharedLib();
                sl.setState(slc.getState());
                sl.setName(name);
                result.add(sl);
            }
        }
        return result;
    }
}
